@@ -62,6 +62,10 @@ sub EXT_controller : Extend('Ext.app.ViewController') : Type('controller') {
             // set material theme
             me.setTheme(me.theme, true);
 
+            this.getViewModel().bind('{session.theme.darkMode}', function (newVal, oldVal, eOpt) {
+                this.setTheme({ darkMode: newVal });
+            }, this);
+
             Ext.util.History.hashbang = true;
 
             // set token and disconnect
@@ -96,12 +100,8 @@ JS
             me.doSignin(null, null, function(res) {
                 if (res.isSuccess()) {
 
-                    // store session
-                    var session = me.checkSession(res.data.session);
-                    me.getViewModel().set('session', session);
-
-                    // store app settings
-                    me.getViewModel().set('settings', res.data.settings);
+                    // get session
+                    var session = me.checkSession(res.data);
 
                     me.setLocale(session.locale, function () {
                         Ext.route.Router.resume();
@@ -143,10 +143,21 @@ JS
                 return this.permissions[role] ? 1 : 0;
             };
 
-            if (!session.locale) session.locale = localStorage.locale || session.default_locale;
+            if (!Ext.isObject(session.locales)) session.locales = {};
+
+            var locale = session.locale || localStorage.locale || session.default_locale;
+
+            if (!session.locales[locale]) locale = session.default_locale;
+
+            session.locale = locale;
+            session.localeName = session.locales[locale];
 
             session.theme = this.theme;
 
+            // update viewModel
+            var viewModel = this.getViewModel();
+            viewModel.set('session', session);
+
             return session;
 JS
 
@@ -157,16 +168,15 @@ JS
                 Ext.manifest.material.toolbar = Ext.manifest.material.toolbar || {};
                 Ext.manifest.material.toolbar.dynamic = true;
 
-                var userTheme = localStorage.theme ? JSON.parse(localStorage.theme) : {},
-                    currentTheme = this.theme;
+                var userTheme = localStorage.theme ? JSON.parse(localStorage.theme) : {};
 
                 if (isDefaultTheme) {
-                    this.theme = Ext.apply(newTheme, userTheme, currentTheme);
+                    this.theme = Ext.apply(newTheme, userTheme);
                 }
                 else {
-                    localStorage.theme = JSON.stringify(newTheme);
+                    this.theme = Ext.apply(this.theme, newTheme);
 
-                    this.theme = Ext.apply(currentTheme, newTheme, userTheme);
+                    localStorage.theme = JSON.stringify(this.theme);
                 }
 
                 Ext.theme.Material.setColors(this.theme);
@@ -217,13 +227,19 @@ JS
 
         # LOCALE
         onSetLocale => func ['locale'], <<"JS",
+
             // already using required locale
             if (Ext.L10N.getCurrentLocale() == locale) return;
 
-            // store user locale in profile, if user is authenticated
-            if (this.getViewModel().get('session').is_authenticated) this.doSetLocale(locale);
+            var me = this,
+                viewModel = me.getViewModel(),
+                session = viewModel.get('session');
 
-            var me = this;
+            // locale is not allowed
+            if (!session.locales[locale]) return;
+
+            // store user locale in profile, if user is authenticated
+            if (session.is_authenticated) this.doSetLocale(locale);
 
             me.setLocale(locale, function () {
                 me.redirectTo(Ext.util.History.getToken(), {force: true});
@@ -231,11 +247,25 @@ JS
 JS
 
         setLocale => func [ 'locale', 'cb' ], <<'JS',
+
+            // already using required locale
             if (locale == Ext.L10N.getCurrentLocale()) {
                 cb();
             }
             else {
-                var me = this;
+                var me = this,
+                    viewModel = me.getViewModel(),
+                    session = viewModel.get('session');
+
+                // locale is not allowed
+                if (!session.locales[locale]) {
+                    cb();
+
+                    return;
+                }
+
+                // update localeName
+                session.localeName = session.locales[locale];
 
                 // store locale in local storage
                 localStorage.locale = locale;
@@ -285,12 +315,8 @@ JS
 
                 if (res.isSuccess()) {
 
-                    // store app settings
-                    me.getViewModel().set('settings', res.data.settings);
-
-                    // store session
-                    var session = me.checkSession(res.data.session);
-                    me.getViewModel().set('session', session);
+                    // get session
+                    var session = me.checkSession(res.data);
 
                     // not authenticated
                     if (!session.is_authenticated) {
